@@ -71,13 +71,12 @@ def upload(dataset, logger, git_diff):
 
 
 @dataset_group.command()
-@click.option('-c', '--commit', default=None, help=messages.PROJECT_DOWNLOAD_HELP_COMMIT)
 @prepare_command()
-def download(dataset, logger, commit):
+def download(dataset, logger):
     """
     Downloads updated files to the current dataset folder
     """
-    dataset.download(progress_bar_enabled=True, commit_sha1=commit)
+    dataset.download(progress_bar_enabled=True)
     logger.log_and_echo(messages.DATA_DOWNLOAD_SUCCESS)
 
 
@@ -110,20 +109,6 @@ def delete(cnvrg, logger, name):
     logger.log_and_echo(success_message)
 
 
-@dataset_group.command()
-@click.option('-j', '--job-slug', default=None, help=messages.PROJECT_JOB_SLUG_HELP_NAME)
-@click.option('-g', '--git-diff', is_flag=True, default=None, help=messages.DATA_UPLOAD_HELP_GIT_DIFF)
-@click.option('-m', '--message', default="", help=messages.DATA_COMMIT_MESSAGE)
-@prepare_command()
-def sync(dataset, logger, message, job_slug=None, git_diff=None):
-    """
-    Sync local project to remote
-    """
-    logger.log_and_echo('Syncing...')
-    dataset.sync(job_slug=job_slug, git_diff=git_diff, progress_bar_enabled=True, message=message)
-    logger.log_and_echo(messages.DATASET_SYNC_SUCCESS.format(dataset.slug))
-
-
 @dataset_group.command()
 @click.option('-n', '--name', prompt=messages.DATASET_PROMPT_CREATE, help=messages.DATASET_HELP_CREATE)
 @prepare_command()
