@@ -12,8 +12,9 @@ def library_group():
 @library_group.command()
 @click.option('-l', '--library', prompt=messages.LIBRARY_PROMPT_CLONE, help=messages.PROJECT_PROMPT_CLONE)
 @click.option('-o', '--override', is_flag=True, default=False, help=messages.PROJECT_HELP_CLONE_OVERRIDE)
+@click.option('-d', '--working-dir', default=None, help=messages.OUTPUT_DIR_LOCATION)
 @prepare_command()
-def clone(cnvrg, logger, library, override):
+def clone(cnvrg, logger, library, working_dir, override):
     """
     Clones the given project to local folder
     """
@@ -28,7 +29,7 @@ def clone(cnvrg, logger, library, override):
     library_version = library.versions.get(version)
 
     click.echo(messages.LOG_CLONING_LIBRARY.format(name, version))
-    library_version.clone(progress_bar_enabled=True)
+    library_version.clone(progress_bar_enabled=True, working_dir=working_dir)
 
     success_message = messages.LIBRARY_CLONE_SUCCESS.format(name)
     logger.log_and_echo(success_message)
