@@ -1,7 +1,9 @@
 import click
-
 from cnvrgv2.cli.utils import messages
 from cnvrgv2.cli.utils.decorators import prepare_command
+from cnvrgv2.cli.utils.helpers import parse_parameters_from_file, build_grid_url, callback_log
+from cnvrgv2.cli.utils.options import PythonLiteralOption
+from cnvrgv2.modules.workflows.workflow_utils import WorkflowUtils, WorkflowStatuses
 
 
 @click.group(name='experiment')
@@ -14,41 +16,59 @@ def experiment_group():
 @click.option('-tm', '--templates', default=None, help=messages.EXPERIMENT_HELP_TEMPLATES)
 @click.option('-l/-nl', '--local/--no-local', default=False, help=messages.EXPERIMENT_HELP_LOCAL)
 @click.option('-c', '--command', prompt=messages.EXPERIMENT_PROMPT_COMMAND, help=messages.EXPERIMENT_HELP_COMMAND)
-@click.option('-d', '--datasets', default=None, help=messages.EXPERIMENT_HELP_DATASETS)
+@click.option('-d', '--datasets', cls=PythonLiteralOption, default=[], help=messages.EXPERIMENT_HELP_DATASETS)
 @click.option('-v', '--volume', default=None, help=messages.EXPERIMENT_HELP_VOLUME)
 @click.option('-sb/-nsb', '--sync-before/--no-sync-before', default=True, help=messages.EXPERIMENT_HELP_SYNC_BEFORE)
 @click.option('-sa/-nsa', '--sync-after/--no-sync-after', default=True, help=messages.EXPERIMENT_HELP_SYNC_AFTER)
 @click.option('-i', '--image', default=None, help=messages.EXPERIMENT_HELP_IMAGE)
 @click.option('-gb', '--git-branch', default=None, help=messages.EXPERIMENT_HELP_GIT_BRANCH)
 @click.option('-gc', '--git-commit', default=None, help=messages.EXPERIMENT_HELP_GIT_COMMIT)
+@click.option('-od', '--output_dir', default=None, help=messages.EXPERIMENT_HELP_OUTPUT_DIR)
+@click.option('-g', '--grid', default=None, help=messages.EXPERIMENT_HELP_GRID)
+@click.option('-lf', '--local_folders', default=None, help=messages.EXPERIMENT_HELP_LOCAL_FOLDERS)
+@click.option('-log', '--log', default=False, help=messages.EXPERIMENT_HELP_LOG)
+@click.option('-w', '--wait', default=False, help=messages.EXPERIMENT_HELP_LOG)
 @prepare_command()
 def run(
-    cnvrg,
-    logger,
-    project,
-    title,
-    templates,
-    local,
-    command,
-    datasets,
-    volume,
-    sync_before,
-    sync_after,
-    image,
-    git_branch,
-    git_commit
+        cnvrg,
+        logger,
+        project,
+        title,
+        templates,
+        local,
+        command,
+        datasets,
+        volume,
+        sync_before,
+        sync_after,
+        output_dir,
+        image,
+        git_branch,
+        git_commit,
+        grid,
+        local_folders,
+        log,
+        wait
 ):
     """
       run an experiment
     """
-    dataset_objects = None
+    dataset_objects = []
     volume_object = None
     kwargs = {}
     templates_list = templates.split(",") if templates else None
 
-    if datasets:
-        dataset_names = datasets.split(",")
-        dataset_objects = [cnvrg.datasets.get(ds_name) for ds_name in dataset_names]
+    for dataset in datasets:
+        if dataset.get("commit") and dataset.get("query"):
+            logger.log_and_echo(messages.EXPERIMENT_DATASET_QUERY_ERROR_MESSAGE.format(dataset.get("slug")),
+                                error=True)
+            return
+        ds = cnvrg.datasets.get(dataset.get("slug"))
+        if dataset.get("commit"):
+            ds.local_commit = dataset.get("commit")
+        if dataset.get("query"):
+            ds.query = dataset.get("query")
+        dataset_objects.append(ds)
 
     if volume:
         volume_object = project.volumes.get(volume)
@@ -63,19 +83,45 @@ def run(
     if git_commit:
         kwargs["git_commit"] = git_commit
 
-    experiment = project.experiments.create(
-        title=title,
-        templates=templates_list,
-        local=local,
-        command=command,
-        datasets=dataset_objects,
-        volume=volume_object,
-        sync_before=sync_before,
-        sync_after=sync_after,
-        **kwargs
-    )
-    success_message = messages.EXPERIMENT_CREATE_SUCCESS.format(experiment.title, experiment.full_href)
-    logger.log_and_echo(success_message)
+    if output_dir:
+        kwargs["output_dir"] = output_dir
+
+    if local_folders:
+        kwargs["local_folders"] = local_folders
+
+    if grid:
+        parsed_parameters = parse_parameters_from_file(grid)
+        kwargs["parameters"] = parsed_parameters
+        grid_slug = project.experiments.create_grid(
+            title=title,
+            templates=templates_list,
+            command=command,
+            datasets=dataset_objects,
+            volume=volume_object,
+            sync_before=sync_before,
+            **kwargs
+        )
+        grid_url = build_grid_url(cnvrg, project, grid_slug)
+        success_message = messages.EXPERIMENT_GRID_CREATE_SUCCESS.format(grid_slug, grid_url)
+        logger.log_and_echo(success_message)
+    else:
+        experiment = project.experiments.create(
+            title=title,
+            templates=templates_list,
+            local=local,
+            command=command,
+            datasets=dataset_objects,
+            volume=volume_object,
+            sync_before=sync_before,
+            sync_after=sync_after,
+            **kwargs
+        )
+        success_message = messages.EXPERIMENT_CREATE_SUCCESS.format(experiment.title, experiment.full_href)
+        logger.log_and_echo(success_message)
+
+        if log or wait:
+            WorkflowUtils.wait_for_statuses(experiment, WorkflowStatuses.FINAL_STATES,
+                                            callback=callback_log(experiment, log))
 
 
 @experiment_group.command()
@@ -145,7 +191,7 @@ def log_images(cnvrg, logger, project, experiment, slug, files):
 @prepare_command()
 def start_tensorboard(experiment, logger, slug):
     """
-      start a tensorboard associated  with the current experiment
+      start a tensorboard session for current experiment
     """
     if experiment is None:
         logger.log_and_echo(messages.EXPERIMENT_DOES_NOT_EXIST, error=True)
@@ -158,7 +204,7 @@ def start_tensorboard(experiment, logger, slug):
 @prepare_command()
 def stop_tensorboard(experiment, logger, slug):
     """
-      stops a tensorboard associated  with the current experiment
+      stop a tensorboard session for current experiment
     """
     if experiment is None:
         logger.log_and_echo(messages.EXPERIMENT_DOES_NOT_EXIST, error=True)
@@ -181,3 +227,21 @@ def pull_artifacts(experiment, logger, slug, commit):
     commit_param = None if commit == 'latest' else commit
     experiment.pull_artifacts(commit_sha1=commit_param)
     logger.log_and_echo(messages.EXPERIMENT_PULL_ARTIFACTS_SUCCESS)
+
+
+@experiment_group.command()
+@click.option('-s', '--slug', default=None, help=messages.EXPERIMENT_HELP_TITLE)
+@click.option('-d', '--delete_artifacts', default=False, help=messages.EXPERIMENT_DELETE_ARTIFACTS, required=False)
+@prepare_command()
+def delete(experiment, logger, slug, delete_artifacts):
+    """
+      delete experiment by slug
+    """
+    if delete_artifacts:
+        user_answer = click.confirm(messages.EXPERIMENT_DELETE_ARTIFACTS_PROMPT, abort=False)
+        if not user_answer:
+            logger.log_and_echo(messages.EXPERIMENT_DELETE_ARTIFACTS_ABORTED, error=True)
+            return
+
+    experiment.delete(delete_artifacts=delete_artifacts)
+    logger.log_and_echo(messages.EXPERIMENT_DELETE_SUCCESS)
