@@ -111,6 +111,16 @@ CONFIG_YAML_NOT_FOUND = "Couldn't find config file. Please clone project/dataset
 MISSING_EXPERIMENT_ARGUMENT = "The function sent as command must get experiment as an argument"
 EXPERIMENT_CANNOT_BE_A_FUNCTION = "Function as command is supported in local experiments only." \
                                   " Add local=True or send a string command instead"
+EXPERIMENT_MISSING_COMMAND_ARGUMENT = "Command Cannot be blank"
+EXPERIMENT_FAULTY_PARAMETERS_INT = "Discrete values may only contain numbers"
+EXPERIMENT_FAULTY_PARAMETERS_LIST = "Values must be of a type list"
+EXPERIMENT_FAULTY_PARAMETERS_VALUES = "values cannot be empty"
+EXPERIMENT_FAULTY_PARAMETERS_STEPS = "The given parameters must be a list of lists of integers"
+EXPERIMENT_FAULTY_PARAMETERS_KEY = "Key cannot be empty"
+EXPERIMENT_FAULTY_PARAMETERS = "Steps should be positive integer"
+EXPERIMENT_FAULTY_PARAMETERS_TYPE = "The given type must be one of the following: [discrete, float, integer, categorical]"
+EXPERIMENT_DUPLICATE_PARAMETERS = "Duplicate keys in parameters {0}"
+
 
 # ENDPOINT
 ENDPOINT_NOT_RUNNING = "Endpoint {0} is not running"
