@@ -123,6 +123,41 @@ def validate_template_type(template_type):
         raise CnvrgArgumentsError(error_messages.TEMPLATE_FAULTY_TYPE)
 
 
+def validate_hyper_parameters(parameters):
+    types = ["discrete", "float", "integer", "categorical"]
+    if parameters and not isinstance(parameters, list):
+        raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS)
+
+    # Check if there is duplicates in the parameters key
+    keys = [param.get("key") for param in parameters]
+    if len(keys) != len(set(keys)):
+        raise CnvrgArgumentsError(error_messages.EXPERIMENT_DUPLICATE_PARAMETERS.format(keys))
+
+    for param in parameters:
+        # Validate parameter name
+        if not param.get("key"):
+            raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS_KEY)
+        # Validate parameter type
+        if param.get("type") not in types:
+            raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS_TYPE)
+        # Validate parameter values
+        if param.get("type") == "discrete":
+            validate_discrete_params(param.get("values"))
+        # Validate parameter step is positive
+        if param.get("steps") and param.get("steps") < 0:
+            raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS_STEPS)
+
+
+def validate_discrete_params(values):
+    if not values:
+        raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS_VALUES)
+    if not isinstance(values, list):
+        raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS_LIST)
+    for value in values:
+        if not isinstance(value, int) and not isinstance(value, float):
+            raise CnvrgArgumentsError(error_messages.EXPERIMENT_FAULTY_PARAMETERS_INT)
+
+
 def _validate_yaml_path(yaml_path):
     """
     Checks the correctness of a YAML file
